@@ -1002,7 +1002,7 @@ void __postconfig_schema_foreach(gpointer key, gpointer value, gpointer userdata
 
 		if ((parenttype = midgard_schema_lookup_type(schema, (gchar *)parentname)) != NULL){
 			// g_debug("type %s, parent %s", typename, parentname); 
-			if (!g_slist_find(parenttype->children, (gpointer) g_strdup(typename))) {
+			if (!g_slist_find_custom(parenttype->children, (gpointer)typename, (GCompareFunc)g_strcmp0)) {
 				parenttype->children = 
 					g_slist_append(parenttype->children, (gpointer) g_strdup(typename));
 			}			
