@@ -71,6 +71,15 @@
 #include <midgard/midgard_executable.h>
 #include <midgard/midgard_validable.h>
 #include <midgard/midgard_repligard.h>
+#include <midgard/midgard_query_row.h>
+#include <midgard/midgard_query_column.h>
+#include <midgard/midgard_query_selector.h>
+#include <midgard/midgard_query_result.h>
+#include <midgard/sql/midgard_sql_query_column.h> 
+#include <midgard/sql/midgard_sql_query_constraint.h>
+#include <midgard/sql/midgard_sql_query_row.h>
+#include <midgard/sql/midgard_sql_query_result.h>
+#include <midgard/sql/midgard_sql_query_select_data.h>
 
 #endif /* _MIDGARD_API_H_ */
 
