@@ -405,8 +405,7 @@ __mysql_reconnect (MidgardConnection *mgd)
 
 		opened = gda_connection_open (mgd->priv->connection, NULL);
 	
-		if (opened) {
-		
+		if (opened) {	
 			g_signal_emit (mgd, MIDGARD_CONNECTION_GET_CLASS (mgd)->signal_id_connected, 0);
 			g_debug ("Successfully reopened connection");
 			return TRUE;
@@ -561,11 +560,13 @@ __midgard_connection_open(MidgardConnection *mgd, gboolean init_schema, GError *
 
 	GError *err = NULL;
 	GdaConnection *connection = gda_connection_open_from_string(
-			config->dbtype, tmpstr, auth, GDA_CONNECTION_OPTIONS_NONE, &err);
+			config->dbtype, 
+			tmpstr, auth, 
+			enable_threads ? GDA_CONNECTION_OPTIONS_THREAD_SAFE : GDA_CONNECTION_OPTIONS_NONE, 
+			&err);
 	g_free(auth);	
 
 	if(connection == NULL) {
-
 		MIDGARD_ERRNO_SET_STRING (mgd, MGD_ERR_NOT_CONNECTED, 
 				" Database [%s]. %s", tmpstr, err->message);
 		if (err) {
