@@ -25,6 +25,8 @@
 
 #include "midgard_defs.h"
 #include "midgard_config.h"
+#include "midgard_workspace_storage.h"
+#include "midgard_workspace_manager.h"
 
 /* convention macros */
 #define MIDGARD_TYPE_CONNECTION (midgard_connection_get_type())
@@ -88,9 +90,14 @@ gchar 			**midgard_connection_list_auth_types		(MidgardConnection *self, guint *
 void			midgard_connection_enable_quota			(MidgardConnection *self, gboolean toggle);
 void			midgard_connection_enable_replication		(MidgardConnection *self, gboolean toggle);
 void			midgard_connection_enable_dbus			(MidgardConnection *self, gboolean toggle);
+void			midgard_connection_enable_workspace		(MidgardConnection *self, gboolean toggle);
 gboolean 		midgard_connection_is_enabled_quota		(MidgardConnection *self);
 gboolean 		midgard_connection_is_enabled_replication	(MidgardConnection *self);
 gboolean 		midgard_connection_is_enabled_dbus		(MidgardConnection *self);
+gboolean 		midgard_connection_is_enabled_workspace		(MidgardConnection *self);
 void			midgard_connection_close			(MidgardConnection *self);
+gboolean                midgard_connection_set_workspace                (MidgardConnection *self, MidgardWorkspaceStorage *workspace);
+const MidgardWorkspaceStorage   *midgard_connection_get_workspace       (MidgardConnection *self);
+const MidgardWorkspaceManager	*midgard_connection_get_workspace_manager (MidgardConnection *self);
 
 #endif /* MIDGARD_CONNNECTION_H */
