@@ -22,19 +22,22 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-/* Read config file  */
-typedef struct
-{
-	gchar *confdir;
-	gchar *blobdir;
-	gchar *sharedir;
-	gchar *vardir;
-	gchar *cachedir;
-}mdirs;
+#define MIDGARD_CONFIG_RW_SCHEMA        "schema"
+#define MIDGARD_CONFIG_RW_SCHEMAS	"schemas"
+#define MIDGARD_CONFIG_RW_VIEW          "view"
+#define MIDGARD_CONFIG_RW_VIEWS		"views"
 
-/* a cached version of paths */
-const mdirs 	*midgard_core_config_get_config_dirs	(void);
-void		midgard_core_config_dirs_free		(mdirs **dirs);
-gchar 		*midgard_core_config_build_path		(const gchar **dirs, const gchar *filename, gboolean user);
+typedef enum { 
+        MIDGARD_DB_TYPE_MYSQL = 1, 
+        MIDGARD_DB_TYPE_POSTGRES, 
+        MIDGARD_DB_TYPE_FREETDS, 
+        MIDGARD_DB_TYPE_SQLITE, 
+        MIDGARD_DB_TYPE_ODBC, 
+        MIDGARD_DB_TYPE_ORACLE 
+} MidgardDBType;
+
+gchar 		*midgard_core_config_build_path			(const gchar **dirs, const gchar *filename, gboolean user);
+gchar		*midgard_core_config_build_schemadir_path	(const gchar *dirname);
+gchar		*midgard_core_config_build_viewdir_path		(const gchar *dirname);
 
 #endif /* MIDGARD_CORE_CONFIG_H */
