@@ -537,8 +537,7 @@ gboolean _nodes2object(GObject *object, xmlNode *node, gboolean force)
 						parser = xmlNewParserCtxt();
 						decoded = 
 							xmlStringDecodeEntities(parser,
-									(const xmlChar *) nodeprop, 
-									XML_SUBSTITUTE_PEREF |
+									(const xmlChar *) nodeprop, 	
 									XML_SUBSTITUTE_REF, 
 									0, 0, 0);
 						g_value_set_string(&pval, 
@@ -573,8 +572,13 @@ gboolean _nodes2object(GObject *object, xmlNode *node, gboolean force)
 						g_object_get(G_OBJECT(object),
 								(const gchar *) cur->name,
 								&prop_object, NULL);
-						_nodes2object(prop_object, cur->children, force);	
-						g_value_set_object(&pval, prop_object);
+						if (prop_object) {
+							_nodes2object(prop_object, cur->children, force);	
+							g_value_set_object(&pval, prop_object);
+						} else {
+							g_warning ("Failed to unserialize '%s' object property. Expected to be initialized by given '%s' instance", (const gchar *) cur->name, G_OBJECT_TYPE_NAME (object));
+						}
+
 						break;
 
 					default:
@@ -695,10 +699,12 @@ GObject **midgard_core_object_from_xml(MidgardConnection *mgd,
 		} else {
 
 			xmlChar *attr = xmlGetProp(child, BAD_CAST "purge");
-			if(g_str_equal(attr, "yes") && MIDGARD_IS_DBOBJECT(object)){
-				g_object_set(object, "action", "purged", NULL);
-				xmlFree(attr);
-				attr = NULL;
+			if(g_str_equal(attr, "yes") && MIDGARD_IS_DBOBJECT(object)) {
+				if (MIDGARD_IS_OBJECT (object)) {
+					g_object_set(object, "action", "purged", NULL);
+					xmlFree(attr);
+					attr = NULL;
+				}
 				
 				attr = xmlGetProp(child, BAD_CAST "guid");
 				MIDGARD_DBOBJECT(object)->dbpriv->guid = 
@@ -724,10 +730,11 @@ GObject **midgard_core_object_from_xml(MidgardConnection *mgd,
 			if(attr)
 				xmlFree(attr);
 
-			xmlChar *action_attr = xmlGetProp(child, BAD_CAST "action");
-			g_object_set(G_OBJECT(object), "action", 
-					(gchar *) action_attr, NULL);
-			xmlFree(action_attr);
+			if (MIDGARD_IS_OBJECT (object)) {
+				xmlChar *action_attr = xmlGetProp(child, BAD_CAST "action");
+				g_object_set(G_OBJECT(object), "action", (gchar *) action_attr, NULL);
+				xmlFree(action_attr);
+			}
 
 			olist = g_slist_prepend(olist, object);
 			_n_nodes++;	
@@ -774,7 +781,8 @@ midgard_core_object_property_refuse_private (MidgardConnection *mgd, MgdSchemaTy
 		MidgardDBObject *object, const gchar *property)
 {
 	/* Unknown case, no connection  */
-	g_return_val_if_fail (mgd != NULL, TRUE);
+	if (mgd == NULL)
+		return FALSE;
 	g_return_val_if_fail (property != NULL, FALSE);
 
 	MgdSchemaTypeAttr *type_attr = type;
