@@ -147,6 +147,7 @@ gboolean midgard_core_object_prop_parent_is_set(MidgardObject *object)
 	if (ptype == G_TYPE_UINT) {
 		
 		guint i = g_value_get_uint(&gval);
+		g_value_unset (&gval);
 		if (i == 0)
 			return FALSE;
 
@@ -155,12 +156,19 @@ gboolean midgard_core_object_prop_parent_is_set(MidgardObject *object)
 	} else if (ptype == G_TYPE_STRING) {
 
 		const gchar *s = g_value_get_string(&gval);
-		if (s == NULL || *s == '\0')
-			return FALSE;
+		gboolean _rv = TRUE;
 
-		return TRUE;
+		if (s == NULL || *s == '\0')
+			_rv = FALSE;
+
+		g_value_unset (&gval);
+
+		return _rv;
 	}
 
+	if (G_IS_VALUE (&gval))
+		g_value_unset (&gval);
+
 	return FALSE;
 }
 
@@ -334,6 +342,7 @@ gboolean midgard_core_object_is_valid(MidgardObject *object)
 					g_clear_error(&MGD_OBJECT_CNC (object)->err);
 					g_free(props);
 					g_free(prop_str);
+					g_object_unref (mrp);
 					return FALSE;
 				}
 			}
@@ -368,6 +377,7 @@ gboolean midgard_core_object_is_valid(MidgardObject *object)
 		}
 	}
 
+	g_object_unref (mrp);
 	g_free(props);
 
 	/* Object metadata */
