@@ -18,6 +18,7 @@
 
 #include "midgard_core_object.h"
 #include "schema.h"
+#include "midgard_base_abstract.h"
 
 typedef struct {
 	GString *string;
@@ -204,30 +205,91 @@ midgard_core_schema_type_attr_new (void)
 	type->metadata_class_name = NULL;
 	type->metadata_class_ptr = NULL;
 	type->user_values = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	type->is_abstract = FALSE;
+	type->is_iface = FALSE;
+	type->is_mixin = FALSE;
+	type->schema = NULL;
 
 	return type;
 }
 
+gchar **
+midgard_core_schema_type_list_extends (MgdSchemaTypeAttr *type_attr, guint *n_types)
+{
+	g_assert (type_attr != NULL);
+	*n_types = 0;
+
+	if (type_attr->extends == NULL)
+		return NULL;
+
+	guint i = 0;
+	gchar **tmp = g_strsplit (type_attr->extends, ",", 0);
+	while (tmp[i] != NULL) {
+		g_strstrip (tmp[i]);
+		i++;
+		*n_types = i;
+	}
+
+	gchar **extends = g_new (gchar*, i+1);
+	i = 0;
+	while (tmp[i] != NULL) {
+		extends[i] = tmp[i];
+	        i++;	
+	}
+
+	extends[i] = NULL;
+
+	g_free (tmp);
+	return extends;
+}
+
 void
 midgard_core_schema_type_attr_extend (MgdSchemaTypeAttr *src, MgdSchemaTypeAttr *dst)
 {
      	g_return_if_fail (src != NULL);
 	g_return_if_fail (dst != NULL);
 
-	g_free (dst->parentfield);
-	dst->parentfield = src->parentfield ? g_strdup (src->parentfield) : NULL;
-	g_free (dst->upfield);
-	dst->upfield = src->upfield ? g_strdup (src->upfield) : NULL;
-	g_free ((gchar *)dst->parent);
-	dst->parent = src->parent ? g_strdup (src->parent) : NULL;
-	g_free ((gchar *)dst->primary);
-	dst->primary = src->primary ? g_strdup (src->primary) : NULL;
-	g_free ((gchar *)dst->primaryfield);
-	dst->primaryfield = src->primaryfield ? g_strdup (src->primaryfield) : NULL;
-	g_free ((gchar *)dst->property_up);
-	dst->property_up = src->property_up ? g_strdup (src->property_up) : NULL;
-	g_free ((gchar *)dst->property_parent);
-	dst->property_parent = src->property_parent ? g_strdup (src->property_parent) : NULL;
+	/* PARENT FIELD */
+	if (src->parentfield) {
+		g_free (dst->parentfield);
+		dst->parentfield = g_strdup (src->parentfield);
+	}
+
+	/* UP FIELD */
+	if (src->upfield) {
+		g_free (dst->upfield);
+		dst->upfield = g_strdup (src->upfield);
+	}
+
+	/* PARENT */
+	if (src->parent) {
+		g_free ((gchar *)dst->parent);
+		dst->parent = g_strdup (src->parent);
+	}
+
+	/* PRIMARY */
+	if (src->primary) {
+		g_free ((gchar *)dst->primary);
+		dst->primary = g_strdup (src->primary);
+	}
+
+	/* PRIMARY FIELD */
+	if (src->primaryfield) {
+		g_free ((gchar *)dst->primaryfield);
+		dst->primaryfield = g_strdup (src->primaryfield);
+	}
+
+	/* PROPERTY UP */
+	if (src->property_up) {
+		g_free ((gchar *)dst->property_up);
+		dst->property_up = g_strdup (src->property_up);
+	}
+
+	/* PROPERTY PARENT */
+	if (src->property_parent) {
+		g_free ((gchar *)dst->property_parent);
+		dst->property_parent = g_strdup (src->property_parent);
+	}
 	
 	if (src->children) {
 		GSList *children;
@@ -236,11 +298,18 @@ midgard_core_schema_type_attr_extend (MgdSchemaTypeAttr *src, MgdSchemaTypeAttr
 		}
 	}
 
-	g_free ((gchar *)dst->unique_name);
-	dst->unique_name = src->unique_name ? g_strdup (src->unique_name) : NULL;
-	g_free ((gchar *)dst->metadata_class_name);
-	dst->metadata_class_name = src->metadata_class_name ? g_strdup (src->metadata_class_name) : NULL;
-	dst->metadata_class_ptr = src->metadata_class_ptr ? src->metadata_class_ptr : NULL;
+	/* UNIQUE NAME */
+	if (src->unique_name) {
+		g_free ((gchar *)dst->unique_name);
+		dst->unique_name = g_strdup (src->unique_name);
+	}
+
+	/* METADATA */
+	if (src->metadata_class_name) {
+		g_free ((gchar *)dst->metadata_class_name);
+		dst->metadata_class_name = g_strdup (src->metadata_class_name);
+		dst->metadata_class_ptr = src->metadata_class_ptr;
+	}
 }
 
 void 
@@ -325,6 +394,11 @@ midgard_core_schema_type_attr_free (MgdSchemaTypeAttr *type)
 	g_hash_table_destroy (type->user_values);
         type->user_values = NULL;
 
+	type->is_iface = FALSE;
+	type->is_mixin = FALSE;
+	type->is_abstract = FALSE;
+	type->schema = NULL;
+
 	g_free (type);
 
 	type = NULL;
@@ -412,9 +486,8 @@ midgard_core_schema_type_initialize_paramspec (MgdSchemaTypeAttr *type)
 	guint n = g_hash_table_size(hash);
 	guint m = n+1;
 
-	if (n < 1) {
-		
-		g_warning("Initializing '%s' type without properties", type->name);
+	if (n < 1) {	
+		g_debug ("Initializing '%s' type without properties", type->name);
 		return;
 	}
 
@@ -484,7 +557,7 @@ midgard_core_schema_type_initialize_paramspec (MgdSchemaTypeAttr *type)
 					property, nick, prop_attr->description,
 					"", G_PARAM_READWRITE);
 		}
-	}	
+	}
 }
 
 void			
@@ -691,3 +764,18 @@ midgard_core_schema_type_property_lookup (MgdSchemaTypeAttr *type, const gchar *
 
 	return g_hash_table_lookup (type->prophash, name);
 }
+
+GType
+midgard_core_schema_register_type (MgdSchemaTypeAttr *type_attr)
+{
+       	GType new_type;
+	if (type_attr->is_abstract) {
+		new_type = midgard_type_register_abstract (type_attr, MIDGARD_TYPE_BASE_ABSTRACT);
+	} else if (type_attr->is_mixin 
+			|| type_attr->is_iface) {
+		new_type = midgard_core_type_register_interface (type_attr);
+	} else {
+		new_type = midgard_type_register(type_attr);
+	}
+	return new_type;
+}
