@@ -120,7 +120,7 @@ static void __get_view_properties(xmlNode *node, MgdSchemaTypeAttr *type)
 
 			MidgardObjectClass *klass = MIDGARD_OBJECT_GET_CLASS_BY_NAME(rprop[0]);		
 			if (!klass)
-				__view_error (cur, "Defined '%s' class is not registered as midagrd_object derived one", rprop[0]);
+				__view_error (cur, "Defined '%s' class is not registered as midgard_object derived one", rprop[0]);
 
 			const gchar *table = midgard_core_class_get_table (MIDGARD_DBOBJECT_CLASS (klass));
 			if (table == NULL)
@@ -151,9 +151,6 @@ static void __get_view_properties(xmlNode *node, MgdSchemaTypeAttr *type)
 				if (prop_attr->table == NULL)
 					prop_attr->table = g_strdup (table);
 
-				/* Free old key and remove new one in hash table */
-				g_hash_table_remove(type->prophash, (gconstpointer) rprop[1]);
-
 				gchar *property_name = g_strdup ((gchar *)name);
 				g_hash_table_insert(type->prophash, property_name, prop_attr);
 
@@ -171,6 +168,8 @@ static void __get_view_properties(xmlNode *node, MgdSchemaTypeAttr *type)
 
 static const gchar *__allowed_joins[] = {"left", "right", "inner", "inner left", "inner right", "outer", NULL };
 
+#define __DBOBJECT_CLASS_PTR(__name) g_type_from_name (__name) == 0 ? NULL : MIDGARD_DBOBJECT_CLASS (g_type_class_peek (g_type_from_name (__name)))
+
 static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 {
 	xmlNode *cur;
@@ -178,8 +177,8 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 	MgdSchemaPropertyAttr *propright = NULL;
 	MgdSchemaPropertyAttr *propleft = NULL;
 	MidgardDBObjectClass *metadata_klass = MIDGARD_DBOBJECT_CLASS (g_type_class_peek (MIDGARD_TYPE_METADATA));
-	MidgardObjectClass *left_klass = NULL;
-	MidgardObjectClass *right_klass = NULL;
+	MidgardDBObjectClass *left_klass = NULL;
+	MidgardDBObjectClass *right_klass = NULL;
 	gchar *left_table = NULL;
 	gchar *right_table = NULL;
 	gchar *left_field = NULL;
@@ -217,7 +216,7 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 			MidgardDBObjectClass *joinklass = NULL;
 
 			if (classname) 
-				joinklass = MIDGARD_DBOBJECT_CLASS(MIDGARD_OBJECT_GET_CLASS_BY_NAME((const gchar *)classname));
+				joinklass = __DBOBJECT_CLASS_PTR ((gchar *)classname);
 
 			if (!joinklass) {
 				g_warning ("%s is not registered in GType system", classname);
@@ -240,12 +239,14 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				return;
 			}
 
-			klass = MIDGARD_DBOBJECT_CLASS(MIDGARD_OBJECT_GET_CLASS_BY_NAME((const gchar *)classprop[0]));
+			klass = __DBOBJECT_CLASS_PTR ((gchar *)classprop[0]);
 			if (!klass) {
 				__view_error(cur, "Class %s not registered", classprop[0]);
 				return;
 			}
 
+			MgdSchemaTypeAttr *type_attr = klass->dbpriv->storage_data;
+
 			/* Set left and right table and field explicitly.
 			 * It's important to ignore  MgdSchemaPropertyAttr in case of metadata usage.
 			 * For this class, we can use explicit table and tablefield, and setting such 
@@ -265,10 +266,10 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				propleft = g_hash_table_lookup(klass->dbpriv->storage_data->prophash, classprop[1]);
 				if (!propleft)
 					__view_error(cur, "Property %s not registered for %s", classprop[1], classprop[0]); 
-				left_table = g_strdup (propleft->table ? propleft->table : type->table);
+				left_table = g_strdup (type_attr->is_view ? type_attr->name : type_attr->table);
 				left_field = g_strdup (propleft->field);
 			}
-			left_klass = MIDGARD_OBJECT_CLASS (klass);
+			left_klass = MIDGARD_DBOBJECT_CLASS (klass);
 			g_strfreev(classprop);	
 
 			/* Get right property attribute */
@@ -284,6 +285,8 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				return;
 			}
 
+			type_attr = klass->dbpriv->storage_data;
+
 			/* Check reserved metadata property */
 			if (g_str_equal (classprop[1], "metadata")) {
 				if (classprop[2] == NULL)
@@ -297,10 +300,10 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				propright = g_hash_table_lookup(klass->dbpriv->storage_data->prophash, classprop[1]);
 				if (!propright)
 					__view_error(cur, "Property %s not registered for %s", classprop[1], classprop[0]);
-				right_table = g_strdup (propright->table ? propright->table : type->table);
+				right_table = g_strdup (type_attr->is_view ? type_attr->name : type_attr->table);
 				right_field = g_strdup (propright->field);
 			}
-			right_klass = MIDGARD_OBJECT_CLASS (klass);
+			right_klass = MIDGARD_DBOBJECT_CLASS (klass);
 			g_strfreev(classprop);
 
 			MidgardDBJoin *mdbj = midgard_core_dbjoin_new();
@@ -401,7 +404,7 @@ static void __get_view_constraints(xmlNode *node, MgdSchemaTypeAttr *type)
 			g_value_transform((const GValue *) &strval, &val);
 		
 			midgard_core_query_constraint_add_value(constraint, &val);
-			midgard_core_query_constraint_build_condition(constraint);
+			//midgard_core_query_constraint_build_condition(constraint);
 
 			type->constraints = g_slist_append(type->constraints, (gpointer) constraint);
 			
@@ -593,9 +596,11 @@ midgard_core_view_build_create_view_command (MidgardConnection *mgd, MidgardDBOb
 
 	for (list = type->constraints; list != NULL; list = list->next) {
 		
-		g_string_append(query, " AND ");
+		if (i > 0)
+			g_string_append(query, " AND ");
 		g_string_append(query,
 				MIDGARD_CORE_QUERY_CONSTRAINT(list->data)->priv->condition);
+		i++;
 	}
 
 	return g_string_free(query, FALSE);
