@@ -14,6 +14,9 @@ typedef struct _MidgardObjectClass MidgardObjectClass;
 typedef struct _MidgardUser MidgardUser; 
 typedef struct _MidgardMetadata MidgardMetadata;
 typedef struct _MidgardMetadataClass MidgardMetadataClass;
+typedef struct _MidgardWorkspace MidgardWorkspace;
+typedef struct _MidgardWorkspacePrivate MidgardWorkspacePrivate;
+typedef struct _MidgardWorkspaceContext MidgardWorkspaceContext;
 
 typedef enum {
 	MIDGARD_AUTHTYPE_NORMAL = 0,
