@@ -139,6 +139,7 @@ gboolean midgard_object_get_by_id(MidgardObject *object, guint id);
 gboolean midgard_object_get_by_guid(MidgardObject *object, const gchar *guid);
 gboolean midgard_object_get_by_path(MidgardObject *self, const gchar *path);
 
+gboolean midgard_object_save(MidgardObject *self);
 gboolean midgard_object_update(MidgardObject *self);
 gboolean midgard_object_create(MidgardObject *object);
 gboolean midgard_object_delete(MidgardObject *object, gboolean check_dependents);
@@ -159,6 +160,8 @@ gboolean midgard_object_lock(MidgardObject *self);
 gboolean midgard_object_is_locked(MidgardObject *self);
 gboolean midgard_object_unlock(MidgardObject *self);
 
+MidgardWorkspace	*midgard_object_get_workspace (MidgardObject *self);
+
 GValue *midgard_object_get_schema_property (MidgardObject *self, const gchar *property);
 void midgard_object_set_schema_property (MidgardObject *self, const gchar *property, GValue *value);
 
