@@ -25,6 +25,7 @@
 #include "midgard_core_query.h"
 #include "midgard_core_object_class.h"
 #include "midgard_core_object.h"
+#include "midgard_validable.h"
 
 struct _MidgardQueryConstraintPrivate {
 	GObject  parent;
@@ -33,6 +34,7 @@ struct _MidgardQueryConstraintPrivate {
 	GdaSqlOperatorType op_type;
 	MidgardQueryStorage *storage;
 	MidgardQueryHolder *holder;
+	gboolean is_valid;
 };
 
 static struct {
@@ -58,7 +60,8 @@ gboolean __query_constraint_operator_is_valid(const gchar *op, GdaSqlOperatorTyp
 	guint i;
 	for (i = 0; valid_operators[i].name != NULL; i++) {
 		if (g_str_equal(op, valid_operators[i].name)) {
-			*op_type = valid_operators[i].op_type;
+			if (op_type)
+				*op_type = valid_operators[i].op_type;
 			return TRUE;
 		}
 	}
@@ -110,7 +113,7 @@ midgard_query_constraint_new (MidgardQueryProperty *property, const gchar *op,
  * midgard_query_constraint_get_storage:
  * @self: #MidgardQueryStorage instance
  *
- * Returns: #MidgardQueryStorage associated with constraint or %NULL
+ * Returns: (transfer none): #MidgardQueryStorage associated with constraint or %NULL
  * Since: 10.05
  */  
 MidgardQueryStorage *
@@ -150,7 +153,7 @@ midgard_query_constraint_set_storage (MidgardQueryConstraint *self, MidgardQuery
  * midgard_query_constraint_get_property:
  * @self: #MidgardQueryConstraint instance
  *
- * Returns: #MidgardQueryProperty associated with @self constraint, or %NULL
+ * Returns: (transfer none): #MidgardQueryProperty associated with @self constraint, or %NULL
  * Since: 10.05
  */ 
 MidgardQueryProperty *
@@ -246,13 +249,16 @@ _midgard_query_constraint_list_constraints (MidgardQueryConstraintSimple *self,
 }
 
 static void 
-__get_expression_value (GValue *src, GString *str)
+__get_expression_value (GdaConnection *cnc, GValue *src, GString *str)
 {
+	gchar *escaped_string = NULL;
 	switch (G_TYPE_FUNDAMENTAL (G_VALUE_TYPE (src))) {
 	
 		case G_TYPE_STRING:
-			  g_string_append_printf (str, "'%s'", g_value_get_string (src));
-			  break;
+			escaped_string = gda_connection_value_to_sql_string(cnc, src);
+			g_string_append_printf (str, "%s", escaped_string);
+			g_free(escaped_string);
+			break;
 
 		case G_TYPE_UINT:
 			  g_string_append_printf (str, "%d", g_value_get_uint (src));
@@ -274,6 +280,7 @@ __get_expression_value (GValue *src, GString *str)
 			  if (G_VALUE_TYPE (src) == G_TYPE_VALUE_ARRAY) {
 				GValueArray *array = (GValueArray *) g_value_get_boxed (src);
 				if (!array) {
+					/* FIXME, add this to validate */
 					g_warning ("Empty array given");
 					return;
 				}
@@ -281,25 +288,26 @@ __get_expression_value (GValue *src, GString *str)
 				for (i = 0; i < array->n_values; i++) {
 					if (i > 0)
 						g_string_append (str, ", ");
-					__get_expression_value (g_value_array_get_nth (array, i), str);
-				}	
-			  } else {
-			  	g_warning ("BOXED type '%s' not implemented \n", G_VALUE_TYPE_NAME (src));
-			  }
-			  break;
+					__get_expression_value (cnc, g_value_array_get_nth (array, i), str);
+				}
+			} else {
+				/*FIXME, add this to validate */
+				g_warning ("BOXED type '%s' not implemented \n", G_VALUE_TYPE_NAME (src));
+			}
+			break;
 
 		default:
-			  break;
+			break;
 	}
 
 	return;
 }
 
 void 
-_midgard_query_constraint_add_conditions_to_statement (MidgardQueryExecutor *executor, MidgardQueryConstraintSimple *constraint_simple, GdaSqlStatement *stmt, GdaSqlExpr *where_expr_node)
+_midgard_query_constraint_add_conditions_to_statement (MidgardQueryExecutor *executor, MidgardQueryConstraintSimple *constraint_simple, GdaSqlStatement *stmt, GdaSqlExpr *where_expr_node, GError **error)
 {	
 	MidgardQueryConstraint *self = MIDGARD_QUERY_CONSTRAINT (constraint_simple);
-	//GdaConnection *cnc = executor->priv->mgd->priv->connection;
+	GdaConnection *cnc = executor->priv->mgd->priv->connection;
 	MidgardDBObjectClass *dbklass = NULL;	
        	if (self->priv->storage && (self->priv->storage != MIDGARD_QUERY_EXECUTOR (executor)->priv->storage)) {
 	       dbklass = self->priv->storage->priv->klass;
@@ -339,11 +347,13 @@ _midgard_query_constraint_add_conditions_to_statement (MidgardQueryExecutor *exe
 	/* Create table_alias.field name */
 	gchar *table_alias_field;
 	expr = gda_sql_expr_new (GDA_SQL_ANY_PART (cond));
+	GError *err = NULL;
 	table_alias_field = midgard_core_query_compute_constraint_property (executor, 
-			MIDGARD_QUERY_CONSTRAINT (constraint_simple)->priv->storage, g_value_get_string (&field_value));
-	if (!table_alias_field)
-		g_warning ("Null table.field alias for given '%s'", g_value_get_string (&field_value));
-	/* TODO, handle error case when table_alias_field is NULL */
+			MIDGARD_QUERY_CONSTRAINT (constraint_simple)->priv->storage, g_value_get_string (&field_value), &err);
+	if (err) {
+		g_propagate_error (error, err);
+		return;
+	}
 	g_value_take_string ((value = gda_value_new (G_TYPE_STRING)), table_alias_field);
 	expr->value = value;
 	cond->operands = g_slist_append (cond->operands, expr);
@@ -362,7 +372,7 @@ _midgard_query_constraint_add_conditions_to_statement (MidgardQueryExecutor *exe
 	//expr->param_spec->g_type = v_type;
 	expr->value = gda_value_new (G_TYPE_STRING);
 	GString *str = g_string_new ("");
-	__get_expression_value (&val, str);
+	__get_expression_value (cnc, &val, str);
 	g_value_take_string (expr->value, g_string_free (str, FALSE));
 	g_value_unset (&val);
 	cond->operands = g_slist_append (cond->operands, expr);
@@ -389,6 +399,55 @@ _midgard_query_constraint_instance_init (GTypeInstance *instance, gpointer g_cla
 	self->priv->op = NULL;
 	self->priv->storage = NULL;
 	self->priv->holder = NULL;
+	self->priv->is_valid = FALSE;
+}
+
+/* Validable iface */
+static void
+_midgard_query_constraint_validable_iface_validate (MidgardValidable *iface, GError **error)
+{
+	g_return_if_fail (iface != NULL);
+	MidgardQueryConstraint *self = MIDGARD_QUERY_CONSTRAINT (iface);
+	self->priv->is_valid = FALSE;
+
+	/* Property */
+	if (MIDGARD_IS_VALIDABLE (self->priv->property_value)) {
+		GError *err = NULL;
+		if (!midgard_validable_is_valid (MIDGARD_VALIDABLE (self->priv->property_value)))
+			midgard_validable_validate (MIDGARD_VALIDABLE (self->priv->property_value), &err);
+		if (err) {
+			g_propagate_error (error, err);
+			return;
+		}
+	}
+
+	/* Storage, TODO */
+
+	/* Value, TODO */
+
+	/* Operator */
+	if (!__query_constraint_operator_is_valid (self->priv->op, NULL)) {
+		g_set_error (error, MIDGARD_VALIDATION_ERROR, MIDGARD_VALIDATION_ERROR_TYPE_INVALID,
+				"Invalid operator type '%s'", self->priv->op);
+		return;
+	}
+
+	MIDGARD_QUERY_CONSTRAINT (self)->priv->is_valid = TRUE;
+	return;
+}
+
+gboolean
+_midgard_query_constraint_validable_iface_is_valid (MidgardValidable *self)
+{
+	g_return_val_if_fail (self != NULL, FALSE);
+	return MIDGARD_QUERY_CONSTRAINT (self)->priv->is_valid;
+}
+
+static void
+_midgard_query_constraint_validable_iface_init (MidgardValidableIFace *iface)
+{
+	iface->validate = _midgard_query_constraint_validable_iface_validate;
+	iface->is_valid = _midgard_query_constraint_validable_iface_is_valid;
 }
 
 static GObject *
@@ -589,8 +648,15 @@ midgard_query_constraint_get_type (void)
 			NULL	/* interface_data */
 		};
 
+		static const GInterfaceInfo validable_info = {
+			(GInterfaceInitFunc) _midgard_query_constraint_validable_iface_init,
+			NULL,	/* interface_finalize */
+			NULL	/* interface_data */
+		};
+
   		type = g_type_register_static (G_TYPE_OBJECT, "MidgardQueryConstraint", &info, 0);
 		g_type_add_interface_static (type, MIDGARD_TYPE_QUERY_CONSTRAINT_SIMPLE, &property_info);
+		g_type_add_interface_static (type, MIDGARD_TYPE_VALIDABLE, &validable_info);
     	}
     	return type;
 }
