@@ -27,6 +27,7 @@
 #include <sql-parser/gda-sql-parser.h>
 #include "midgard_core_workspace.h"
 #include "midgard_workspace_storage.h"
+#include "midgard_core_config.h"
 
 /**
  * midgard_query_select_new:
@@ -36,7 +37,7 @@
  * #MidgardStorage @storage represents storage which is queried during execution
  *
  * By default, for performance reason, MidgardQuerySelect is instantiated in read only mode.
- * See: midgard_query_select_read_only().
+ * See: midgard_query_select_toggle_read_only().
  *
  * Returns: new #MidgardQuerySelect instance or %NULL on failure
  * Since: 10.05
@@ -93,15 +94,15 @@ typedef struct {
 } qso;
 
 gboolean
-_midgard_query_select_add_order (MidgardQueryExecutor *self, MidgardQueryProperty *property, const gchar *type)
+_midgard_query_select_add_order (MidgardQueryExecutor *self, MidgardQueryHolder *holder, const gchar *type)
 {
 	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (property != NULL, FALSE);
+	g_return_val_if_fail (holder != NULL, FALSE);
 
 	qso *_qs = g_new (qso, 1);
 	_qs->order_type = g_strdup (type);
 	_qs->asc = FALSE;
-	_qs->property = g_object_ref (property);
+	_qs->property = g_object_ref (holder);
 
 	self->priv->orders = g_slist_append (self->priv->orders, _qs);
 
@@ -209,8 +210,6 @@ gboolean __query_select_add_orders (MidgardQueryExecutor *self, GError **error)
 		
 		if (property->priv && property->priv->storage)
 			storage = property->priv->storage;
-		else 
-			storage = MIDGARD_QUERY_EXECUTOR (self)->priv->storage;
 
 		/* Compute table.colname for given property name */
 		GValue rval = {0, };
@@ -247,6 +246,8 @@ gboolean __query_select_add_orders (MidgardQueryExecutor *self, GError **error)
 	return TRUE;
 }
 
+#define __BOOL_VALUE(__bool)(__bool ? "0" : "FALSE")
+
 static void
 __add_implicit_workspace_join (MidgardQuerySelect *self, GdaSqlOperation *operation)
 {
@@ -264,6 +265,8 @@ __add_implicit_workspace_join (MidgardQuerySelect *self, GdaSqlOperation *operat
 	if (!MGD_CNC_HAS_WORKSPACE (mgd))
 		return;
 
+	gboolean bool_is_int = MIDGARD_QUERY_EXECUTOR (self)->priv->bool_is_int;
+
 	guint ws_id = MGD_CNC_WORKSPACE_ID (mgd);
 	MidgardQueryExecutor *executor = MIDGARD_QUERY_EXECUTOR (self);
 	GdaSqlStatement *sql_stm = executor->priv->stmt;
@@ -273,25 +276,35 @@ __add_implicit_workspace_join (MidgardQuerySelect *self, GdaSqlOperation *operat
 	const gchar *klass_table = MGD_DBCLASS_TABLENAME (klass);
 
 	gchar *left_table = executor->priv->table_alias;
-	gchar *right_table = g_strdup_printf ("t%d", ++executor->priv->tableid);
+	//gchar *right_table = g_strdup_printf ("t%d", ++executor->priv->tableid);
+	gchar *right_table = g_strdup ("midgard_ws_tmp_table");
 
 	join = gda_sql_select_join_new (GDA_SQL_ANY_PART (from));
 	join->type = GDA_SQL_SELECT_JOIN_INNER;
 
 	GdaSqlExpr *expr = gda_sql_expr_new (GDA_SQL_ANY_PART (join));
 	expr->value = gda_value_new (G_TYPE_STRING);
-	g_value_take_string (expr->value, g_strdup_printf ("%s.%s = %s.%s", 
+	g_value_take_string (expr->value, g_strdup_printf ("%s.%s = %s.%s",
 				left_table, MGD_WORKSPACE_ID_FIELD, right_table, MGD_WORKSPACE_ID_FIELD));
 
 	join->expr = expr;
 	join->position = ++executor->priv->joinid;
 
-	const gchar *deleted_field = midgard_core_object_get_deleted_field (klass);
+	MidgardConfig *config = mgd->priv->config;
+	const gchar *sql_part_bool_func_start = "";
+	const gchar *sql_part_bool_func_end = "";
+	const gchar *deleted_field = midgard_core_object_get_deleted_field (klass);	
 	GString *table = g_string_new ("(SELECT DISTINCT MAX");
-	g_string_append_printf (table, "(%s) AS %s, %s %s%s FROM %s WHERE %s IN (0,", 
+	if (config->priv->dbtype == MIDGARD_DB_TYPE_POSTGRES && deleted_field) {
+		sql_part_bool_func_start = " bool_or(";
+		sql_part_bool_func_end = ") AS metadata_deleted";
+	}
+	g_string_append_printf (table, "(%s) AS %s, %s %s%s%s%s FROM %s WHERE %s IN (0,",
 			MGD_WORKSPACE_ID_FIELD, MGD_WORKSPACE_ID_FIELD, MGD_WORKSPACE_OID_FIELD, 
 			deleted_field ? "," : "",
+			sql_part_bool_func_start,
 			deleted_field ? deleted_field : "",
+			sql_part_bool_func_end,
 			klass_table, MGD_WORKSPACE_ID_FIELD);
 
 	const MidgardWorkspaceStorage *ws = midgard_connection_get_workspace (mgd);
@@ -311,7 +324,7 @@ __add_implicit_workspace_join (MidgardQuerySelect *self, GdaSqlOperation *operat
 		g_string_append (table, "0");
 	g_string_append (table, ") ");  
 	if (deleted_field)
-		g_string_append_printf (table, "AND %s = 0 ", deleted_field);
+		g_string_append_printf (table, "AND %s = %s ", deleted_field, __BOOL_VALUE (bool_is_int));
 	g_string_append_printf (table, "GROUP BY %s)", MGD_WORKSPACE_OID_FIELD);
 	g_slist_free (list);
 
@@ -411,10 +424,11 @@ gboolean __query_select_add_joins (MidgardQuerySelect *self, GdaSqlOperation *op
 }
 
 static void 
-__add_exclude_deleted_constraints (GdaSqlStatementSelect *select, GdaSqlOperation *operation, MidgardDBObjectClass *dbklass)
+__add_exclude_deleted_constraints (MidgardQueryExecutor *self, GdaSqlStatementSelect *select, GdaSqlOperation *operation, MidgardDBObjectClass *dbklass)
 {
 	GSList *l = select->from->targets;
 	const gchar *deleted_field = midgard_core_object_get_deleted_field (dbklass);
+	gboolean bool_is_int = MIDGARD_QUERY_EXECUTOR (self)->priv->bool_is_int;
 
 	/* We have only one target table, so create one expression and add to top operation */
 	if (g_slist_length (l) == 1) {
@@ -425,7 +439,7 @@ __add_exclude_deleted_constraints (GdaSqlStatementSelect *select, GdaSqlOperatio
 		GdaSqlSelectTarget *target = (GdaSqlSelectTarget *) l->data;
 		GdaSqlExpr *expr = gda_sql_expr_new (GDA_SQL_ANY_PART (operation));
 		expr->value = gda_value_new (G_TYPE_STRING);
-		g_value_take_string (expr->value, g_strdup_printf ("%s.%s = 0", target->as, deleted_field));
+		g_value_take_string (expr->value, g_strdup_printf ("%s.%s = %s", target->as, deleted_field, __BOOL_VALUE (bool_is_int)));
 		operation->operands = g_slist_append (operation->operands, expr);
 
 		return;
@@ -444,7 +458,7 @@ __add_exclude_deleted_constraints (GdaSqlStatementSelect *select, GdaSqlOperatio
 		GdaSqlSelectTarget *target = (GdaSqlSelectTarget *) l->data;
 		GdaSqlExpr *expr = gda_sql_expr_new (GDA_SQL_ANY_PART (operation));
         	expr->value = gda_value_new (G_TYPE_STRING);
-        	g_value_take_string (expr->value, g_strdup_printf ("%s.metadata_deleted = 0", target->as));
+        	g_value_take_string (expr->value, g_strdup_printf ("%s.metadata_deleted = %s", target->as, __BOOL_VALUE (bool_is_int)));
         	deleted_operation->operands = g_slist_append (deleted_operation->operands, expr);
 	}
 }
@@ -504,8 +518,13 @@ _midgard_query_select_validable_iface_validate (MidgardValidable *iface, GError
 
 	GError *err = NULL;
 	MidgardQueryStorage *storage = MIDGARD_QUERY_EXECUTOR (self)->priv->storage;
-	GObjectClass *klass = MIDGARD_QUERY_EXECUTOR (self)->priv->storage->priv->klass;
-	const gchar *table = midgard_core_class_get_table (klass);
+	GObjectClass *klass = (GObjectClass *) storage->priv->klass;
+	if (klass == NULL || (!G_IS_OBJECT_CLASS(klass))) {
+		g_set_error (error, MIDGARD_VALIDATION_ERROR, MIDGARD_VALIDATION_ERROR_TYPE_INVALID,
+				"Invalid '%s' classname associated with QueryStorage", storage->priv->classname);
+		return;
+	}
+	const gchar *table = midgard_core_class_get_table (MIDGARD_DBOBJECT_CLASS (klass));
 
 	/* Class table */
 	if (!table) {
@@ -651,8 +670,8 @@ _midgard_query_select_executable_iface_execute (MidgardExecutable *iface, GError
 	if (MIDGARD_QUERY_EXECUTOR (self)->priv->constraint) {
 		MIDGARD_QUERY_CONSTRAINT_SIMPLE_GET_INTERFACE (MIDGARD_QUERY_EXECUTOR (self)->priv->constraint)->priv->add_conditions_to_statement 			(MIDGARD_QUERY_EXECUTOR (self), MIDGARD_QUERY_EXECUTOR (self)->priv->constraint, sql_stm, base_where, &err);
 		if (err) {
-			g_set_error(error, err->domain, err->code, "%s", err->message ? err->message : "Unknown error");
-			g_clear_error(&err);
+			g_propagate_error (error, err);
+			goto return_false;
 		}
 		if (MIDGARD_QUERY_EXECUTOR (self)->priv->n_constraints == 1) 
 			__add_second_dummy_constraint (sss, operation);
@@ -674,7 +693,7 @@ _midgard_query_select_executable_iface_execute (MidgardExecutable *iface, GError
 
 	/* Exclude deleted */
 	if (MGD_DBCLASS_METADATA_CLASS (klass) && !executor->priv->include_deleted)
-		__add_exclude_deleted_constraints (sss, operation, klass);
+		__add_exclude_deleted_constraints (executor, sss, operation, klass);
 
 	/* Add limit, LIMIT x */
 	if (executor->priv->limit > 0) {
@@ -967,7 +986,12 @@ __midgard_query_select_set_property (GObject *object, guint property_id,
 		case PROPERTY_CONNECTION:
 			if (!G_VALUE_HOLDS_OBJECT (value))
 				return;
-			MIDGARD_QUERY_EXECUTOR (self)->priv->mgd = g_value_dup_object (value);	
+			MIDGARD_QUERY_EXECUTOR (self)->priv->mgd = g_value_dup_object (value);
+			/* In case of SQLite provider, use integer instead of boolean type,
+			 * which is not supported in SQLite */ 
+			MidgardConfig *config = MIDGARD_QUERY_EXECUTOR (self)->priv->mgd->priv->config;
+			if (config->priv->dbtype == MIDGARD_DB_TYPE_SQLITE)
+				MIDGARD_QUERY_EXECUTOR (self)->priv->bool_is_int = TRUE;	
 			break;
 
 		case PROPERTY_STORAGE:
