@@ -37,21 +37,20 @@
 typedef struct _MidgardReplicatorPrivate MidgardReplicatorPrivate;
 
 typedef struct _MidgardReplicator MidgardReplicator;
-typedef struct _MidgardReplicator midgard_replicator;
 
-struct _MidgardReplicator{
+struct _MidgardReplicator {
 	GObject parent;
 };
 
 typedef struct MidgardReplicatorClass MidgardReplicatorClass;
 
-struct MidgardReplicatorClass{
+struct MidgardReplicatorClass {
 	GObjectClass parent;
 	
 	/* API methods */
 	gchar 		*(*serialize)		(GObject *object);
 	gboolean	(*export)		(MidgardDBObject *object);
-	gchar 		*(*export_purged)	(MidgardConnection *mgd, MidgardDBObjectClass *klass, const gchar *startdate, const gchar *enddate);
+	gchar 		*(*export_purged)	(MidgardConnection *mgd, const gchar *classname, const gchar *startdate, const gchar *enddate);
 	gchar 		*(*serialize_blob)	(MidgardObject *object);
 	gchar 		*(*export_blob)		(MidgardObject *object);
 	gboolean 	(*export_by_guid)	(const gchar *guid);
@@ -61,11 +60,11 @@ struct MidgardReplicatorClass{
 	void		(*import_from_xml)	(MidgardConnection *mgd, const gchar *xml, gboolean force);
 };
 
-GType midgard_replicator_get_type(void);
+GType midgard_replicator_get_type (void);
 
 gchar 			*midgard_replicator_serialize		(GObject *object);
 gboolean 		midgard_replicator_export		(MidgardDBObject *object);
-gchar 			*midgard_replicator_export_purged	(MidgardConnection *mgd, MidgardObjectClass *klass, const gchar *startdate, const gchar *enddate);
+gchar 			*midgard_replicator_export_purged	(MidgardConnection *mgd, const gchar *classname, const gchar *startdate, const gchar *enddate);
 gchar 			*midgard_replicator_serialize_blob	(MidgardObject *object);
 gchar 			*midgard_replicator_export_blob		(MidgardObject *object);
 gboolean 		midgard_replicator_export_by_guid 	(MidgardConnection *mgd, const gchar *guid);
