@@ -21,9 +21,9 @@
 #ifndef _MIDGARD_UTIL_H_
 #define _MIDGARD_UTIL_H_
 
-const char *midgard_version();
-void midgard_init();
-void midgard_close();
+const char *midgard_version(void);
+void midgard_init(void);
+void midgard_close(void);
 
 #endif /* _MIDGARD_UTIL_H_ */
 
