@@ -26,6 +26,7 @@
 #include "midgard_connection.h"
 #include "midgard_core_config.h"
 #include "midgard_error.h"
+#include "query_constraint.h"
 
 static GObjectClass *__view_parent_class= NULL;
 
@@ -78,7 +79,7 @@ __midgard_view_derived_object_set_from_sql(MidgardConnection *mgd, GType type, c
 
 /* Create GdaSqlSelectField for every property registered for the class. */
 static void
-__midgard_view_derived_add_fields_to_select_statement (MidgardDBObjectClass *klass, GdaConnection *cnc, GdaSqlStatementSelect *select, const gchar *table_name)
+__midgard_view_derived_add_fields_to_select_statement (MidgardDBObjectClass *klass, MidgardConnection *mgd, GdaSqlStatementSelect *select, const gchar *table_name)
 {
 	guint n_prop;
 	guint i;
@@ -86,6 +87,8 @@ __midgard_view_derived_add_fields_to_select_statement (MidgardDBObjectClass *kla
 	GdaSqlExpr *expr;
 	GValue *val;
 	gchar *table_field;
+	GdaConnection *cnc = mgd->priv->connection;
+
 	GParamSpec **pspecs = g_object_class_list_properties (G_OBJECT_CLASS (klass), &n_prop);
 	if (!pspecs)
 		return;
@@ -171,6 +174,11 @@ _midgard_view_derived_object_get_property (GObject *object, guint prop_id,
 	const GValue *dvalue = 
 		midgard_data_model_get_value_at_col_name(self->dbpriv->datamodel, pspec->name, self->dbpriv->row);
 
+	/* There migh be explicit NULL returned from query in case of used join(s).
+	 * Ignore it silently */
+	if (!G_IS_VALUE (dvalue))
+		return;
+
 	// Hack to workaround bug in gda-sqlite (returns INVALID for empty strings)
 	if (G_VALUE_HOLDS (dvalue, G_TYPE_INVALID) && G_VALUE_HOLDS_STRING (value)) {
 
@@ -199,7 +207,13 @@ _midgard_view_derived_create_storage (MidgardConnection *mgd, MidgardDBObjectCla
 	g_return_val_if_fail(klass != NULL, FALSE);
 
 	MgdSchemaTypeAttr *type_attr = midgard_core_class_get_type_attr(klass);
-	
+
+	/* Build view condition if there's at least one constraint defined. */
+	GSList *l;
+	for (l = type_attr->constraints; l != NULL; l =l->next) {
+		midgard_core_query_constraint_build_condition (mgd, (MidgardCoreQueryConstraint *)l->data);
+	}	
+
 	/* Do not depend on CREATE VIEW IF NOT EXISTS */
 	if (_midgard_view_derived_storage_exists (mgd, klass)) {
 
