@@ -65,30 +65,14 @@ static gboolean __type_is_valid(GType type)
 	if(!_type)
 		return FALSE;
 
-	if(type == MIDGARD_TYPE_DBOBJECT 
-			|| type == MIDGARD_TYPE_OBJECT)
+	if (g_type_is_a (type, MIDGARD_TYPE_DBOBJECT))
 		return TRUE;
 
-	/* check MIDGARD_TYPE_OBJECT */
-	if(g_type_parent(_type) != MIDGARD_TYPE_DBOBJECT) {
-		
-		/* if fails, try MIDGARD_TYPE_DBOBJECT */
-		if(g_type_parent(_type) == MIDGARD_TYPE_OBJECT
-				|| g_type_parent(_type) == MIDGARD_TYPE_VIEW) {
-			
-			return TRUE;
-		
-		} else {
-
-			return FALSE;
-		}
-	}
-
-	return TRUE;
+	return FALSE;
 }
 
 /**
- * midgard_query_builder_new():
+ * midgard_query_builder_new:
  * @mgd: #MidgardConnection instance
  * @classname: any #MidgardDBObjectClass derived class' name
  *
@@ -159,6 +143,8 @@ MidgardQueryBuilder *midgard_query_builder_new(
  * This function is added for language bindings, in which, that function
  * can not be invoked explicitly.
  *
+ * Returns: (transfer full): new #MidgardQueryBuilder instance
+ *
  * Since: 10.05.1
  */
 MidgardQueryBuilder *
@@ -175,7 +161,7 @@ void midgard_query_builder_free(MidgardQueryBuilder *builder)
 }
 
 /**
- * midgard_query_builder_add_constraint():
+ * midgard_query_builder_add_constraint:
  * @builder: #MidgardQueryBuilder instance
  * @name: property name used for this constraint 
  * @op: comparison operator
@@ -278,7 +264,7 @@ gboolean midgard_query_builder_add_constraint(
 	if(!midgard_core_query_constraint_add_value(constraint, value))
 		goto return_false;
 	
-	if (!midgard_core_query_constraint_build_condition(constraint))
+	if (!midgard_core_query_constraint_build_condition(NULL, constraint))
 		goto return_false;
 
 	/* FIXME, table should be stored per every constraint, order, whatever */
@@ -354,7 +340,7 @@ gboolean midgard_query_builder_add_constraint_with_property(
 
 	constraint->priv->condition_operator = g_strdup(op);
 
-	if (!midgard_core_query_constraint_build_condition(constraint))
+	if (!midgard_core_query_constraint_build_condition(NULL, constraint))
 		goto return_false;
 
 	midgard_core_qb_add_table(builder, constraint->priv->prop_left->table);
@@ -619,7 +605,7 @@ static GSList *midgard_query_builder_execute_or_count(MidgardQueryBuilder *build
  * 
  * In case of any error, #MidgardConnection error is set.
  * 
- * Returns: NULL terminated array of objects, or NULL if none found
+ * Returns: (transfer full): NULL terminated array of objects, or NULL if none found
  */  
 GObject **midgard_query_builder_execute(
 	MidgardQueryBuilder *builder, guint *n_objects)
